from flag_bearer.config import Config
from argparse import Namespace

def test_load():
    c = Config.load(noflagrc=True)
    assert c.get('iscore', 'api_version') == 'v1'
    assert c.get('iscore', 'base_url') == 'https://iscore.iseage.org'


def test_merge():
    c = Config.load(noflagrc=True)

    args = Namespace(api_token='abcd', iscore_url=None, api_version=None, save=False)

    c.merge(args)
    assert c.api_token == 'abcd'
    assert c.get('iscore', 'base_url') == 'https://iscore.iseage.org'
    assert c.get('iscore', 'api_version') == 'v1'
    assert not c.has_option('iscore', 'force_save')


def test_extras():
    c = Config.load(noflagrc=True)
    args = Namespace(api_token='abcd', iscore_url=None, api_version=None, save=False)
    c.merge(args)

    extras = c.request_extras()

    assert 'Authorization' in extras['headers']
    assert extras['headers']['Authorization'] == 'Token abcd'




import vcr
import pytest

from argparse import Namespace

from flag_bearer import utils
from flag_bearer.config import Config


@pytest.fixture
def config():
    conf = Config.load(noflagrc=True)
    args = Namespace(api_token='32257d57fcae845fc89db97a0835c78b60fb8adb', iscore_url='http://localhost:8000', api_version=None, save=False)
    conf.merge(args)
    return conf


@vcr.use_cassette('fixtures/vcr_cassettes/user.yaml')
def test_user_profile(config):
    user = utils.get_user(config)

    assert user['is_superuser']
    assert user['username'] == 'admin'


@vcr.use_cassette('fixtures/vcr_cassettes/flags.yaml')
def test_get_flags(config):
    flags = utils.get_flags(config, team=3)

    print(flags)
    assert len(flags) > 0
    assert flags[0]['team_number'] == 3
    assert len(flags[0]['data']) == 50




import requests
import sys


def get_api_url(conf):
    return "{}/api/{}".format(conf.get('iscore', 'base_url'),
                              conf.get('iscore', 'api_version'))


def get_user(conf):
    api_url = get_api_url(conf)
    extras = conf.request_extras()
    resp = requests.get(api_url + "/user/show.json", **extras)
    if resp.status_code == 403:
        print("[!!] Unauthorized: Invalid authentication information")
        sys.exit(1)

    resp.raise_for_status()
    resp = resp.json()

    return resp


def get_flags(conf, team=None):
    api_url = get_api_url(conf)
    extras = conf.request_extras()

    url = api_url + '/flags.json'

    if team:
        url += "?team_number={}".format(team)

    resp = requests.get(url, **extras)
    resp.raise_for_status()
    resp = resp.json()

    if team:
        resp = list(filter(lambda x: x['team_number'] == team, resp))

    return resp



from __future__ import print_function
from six.moves import input
import requests
import sys
import os

from flag_bearer import utils


def plant(conf):
    resp = utils.get_user(conf)

    team = None
    red = resp['profile']['is_red']
    admin = resp['is_superuser']
    if red or admin:
        print("Which team do you want to get flags for?")
        try:
            team = int(input("> "))
        except ValueError:
            print("Retreiving flags for all teams")

    resp = utils.get_flags(conf, team)
    flags = {i: x for i, x in enumerate(resp)}

    print("Pick the flag to place")
    for flag_id, flag in flags.items():
        # Admins can see both blue and red flags, tell them which is which
        if admin:
            print("{}. {} ({})".format(flag_id, flag['name'], flag['type']))
        else:
            print("{}. {}".format(flag_id, flag['name']))

    flag = int(input("> "))

    if flag not in flags:
        print("[!!] Invalid selection")
        sys.exit(1)

    flag = flags[flag]

    save = conf.has_option('iscore', 'force_save') if red or admin else True
    if save or (not red and not admin):
        print("Where should I put the flag?")
        location = input("(./) > ")

        if not location:
            location = "./"

        print("Placing {} flag in {}".format(flag['name'], location))
        with open(os.path.join(location, flag['filename']), 'w') as fp:
            fp.write(flag['data'])
            fp.write("\n")
    else:
        print("Flag: {}".format(flag['data']))




from argparse import ArgumentParser
from flag_bearer import __version__, actions, config


parser = ArgumentParser()
parser.add_argument('--iscore-url', help="IScorE base url", default=None)
parser.add_argument('--api-version', default='v1')
parser.add_argument('--api-token')
subparsers = parser.add_subparsers()


plant = subparsers.add_parser('plant')
plant.set_defaults(func=actions.plant)
plant.add_argument('-f', '--flag', help="The name of the flag to plant")
plant.add_argument('-l', '--location', help="The location to plant the flag")
plant.add_argument('-n', '--team', help="The team number")
plant.add_argument('-s', '--save', action='store_true', default=False, 
                   help="Force the flag to be downloaded")


def main():
    print("Flag Bearer v{}".format(__version__))
    args = parser.parse_args()

    if not hasattr(args, 'func'):
        parser.print_help()
        return

    conf = config.Config.load()
    conf.merge(args)
    args.func(conf)




#!/usr/bin/env python
import os
import re
from setuptools import setup, find_packages
from flag_bearer import __version__


ROOT = os.path.dirname(__file__)


def parse_requirements(filename):
    requirements = []
    for line in open(filename, 'r').read().split('\n'):
        # Skip comments
        if re.match(r'(\s*#)|(\s*#)', line):
            continue
        requirements.append(line)

    return requirements


def read(fname):
    return open(os.path.join(ROOT, fname)).read()


setup(
    name='flag-bearer',
    version=__version__,
    url='http://github.com/ISEAGE-ISU/flag-bearer',
    description='CDC IScorE Flag Utility',
    long_description=read('README.md'),
    author='ISEAGE',
    author_email='iseage@iastate.edu',
    license='MIT',
    packages=find_packages(),

    setup_requires=[
        'pytest-runner',
    ],
    install_requires=parse_requirements(os.path.join(ROOT, 'requirements.txt')),
    tests_require=[
        'vcrpy',
        'pytest',
        'tox',
    ],

    classifiers=[
        'Development Status :: 4 - Beta',

        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',

        'Topic :: Internet :: WWW/HTTP',

        'License :: OSI Approved :: MIT License',
    ],

    entry_points={
        'console_scripts': [
            'flag-bearer=flag_bearer.cli:main',
        ]
    },
    package_data={
        'flag_bearer': ['default.ini'],
    },
)

